#
# ovirt-engine-setup -- ovirt engine setup
# Copyright (C) 2014 Red Hat, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

"""
RedHat monitoring plugin.
"""

import os
import gettext
_ = lambda m: gettext.dgettext(message=m, domain='ovirt-engine-setup')


from otopi import util
from otopi import plugin


from ovirt_engine_setup import constants as osetupcons
from ovirt_engine_setup import dialog
from ovirt_engine_setup import rhsc_constants as rhsccons


@util.export
class Plugin(plugin.PluginBase):
    """
    RedHat monitoring plugin.
    """
    def __init__(self, context):
        super(Plugin, self).__init__(context=context)

    @plugin.event(
        stage=plugin.Stages.STAGE_INIT,
    )
    def _init(self):
        self.environment.setdefault(
            rhsccons.MonitoringEnv.NAGIOS_MONITORING_ENABLED,
            None
        )

    @plugin.event(
        stage=plugin.Stages.STAGE_CUSTOMIZATION,
    )
    def _customization(self):
        """
        Request monitoring parameters and update the corresponding
        configuration file, /etc/ovirt-engine/monitoring.conf
        """
        if self.environment[
            rhsccons.MonitoringEnv.NAGIOS_MONITORING_ENABLED
        ] is None:
            self.environment[
                rhsccons.MonitoringEnv.NAGIOS_MONITORING_ENABLED
            ] = dialog.queryBoolean(
                dialog=self.dialog,
                name='OVESETUP_MONITORING_ENABLED',
                note=_(
                    'Would you like external monitoring to be enabled? '
                    '(@VALUES@) [@DEFAULT@]: '
                ),
                prompt=True,
                true=_('Yes'),
                false=_('No'),
                default=True,
            )

    @plugin.event(
        stage=plugin.Stages.STAGE_MISC,
    )
    def _misc(self):
        if self.environment[rhsccons.MonitoringEnv.NAGIOS_MONITORING_ENABLED]:
            flag_value = 'true'
        else:
            flag_value = 'false'

        content = "{\"enabled\": %s}" % flag_value

        filename = rhsccons.FileLocations.MONITORING_PLUGIN_CONFIG
        filepath = filename[:filename.rindex("/")]
        if not os.path.exists(filepath):
            os.makedirs(filepath)

        with open(filename, "w") as f:
            f.write(content)

    @plugin.event(
        stage=plugin.Stages.STAGE_CLOSEUP,
        condition=lambda self: self.environment[
            rhsccons.MonitoringEnv.NAGIOS_MONITORING_ENABLED
        ],
    )
    def _closeup(self):
        for service in ('nagios', 'nsca'):
            for state in (False, True):
                self.services.state(name=service, state=state)
            self.services.startup(name=service, state=True)

    @plugin.event(
        stage=plugin.Stages.STAGE_CLOSEUP,
        condition=lambda self: self.environment[
            rhsccons.MonitoringEnv.NAGIOS_MONITORING_ENABLED
        ],
        before=(
            osetupcons.Stages.DIALOG_TITLES_E_SUMMARY,
        ),
        after=(
            osetupcons.Stages.DIALOG_TITLES_S_SUMMARY,
        ),
    )
    def _closeupMessage(self):
        self.logger.info(
            _(
                'To enable monitoring, ensure that the managed nodes are '
                'migrated to Red Hat Storage-3.0. Also ensure that the '
                'auto-discovery command (configure-gluster-nagios) is executed'
                ' to start monitoring the Red Hat Storage Nodes after the '
                'nodes are added to Red Hat Storage Console. For more details,'
                ' refer Red Hat Storage Console Administration Guide.'
            )
        )

# vim: expandtab tabstop=4 shiftwidth=4
