#!/bin/sh
#
# rhsc_monitoring -- RHSC setup plugin to enable/disable monitoring
# Copyright (C) 2014 Red Hat, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

function nagios_status
{
    status=$(service nagios status)
    if echo "$status" | egrep -q "is running"
    then
        echo "Nagios is running"
    elif echo "$status" | egrep -q "No lock file found"
    then
        echo "Nagios is not running"
    fi
}

function nsca_status
{
    status=$(service nsca status)
    if echo "$status" | egrep -q "is running"
    then
        echo "NSCA is running"
    elif echo "$status" | egrep -q "nsca is stopped"
    then
        echo "NSCA is not running"
    fi
}

function enable_monitoring
{
    ret=`egrep "\"enabled\":.*true" $cfgfile`
    if [ "$ret" != "" ]
    then
        echo "RHSC Monitoring is already enabled"
    else
        # Set the value of flag
        echo "Setting the monitoring flag..."
        sed 's/"enabled":.*false/"enabled": true/g' $cfgfile > ${cfgfile}_tmp
        mv ${cfgfile}_tmp $cfgfile

        # Start the services
        if echo $(nagios_status) | egrep -q "is not running"
        then
	        service nagios start
        fi
        if echo $(nsca_status) | egrep -q "is not running"
        then
	        service nsca start
        fi

        echo "INFO: Move the nodes of existing cluster (with compatibilty version >= 3.4) to maintenance and re-install them."
        echo "Ensure that the auto-discovery command (configure-gluster-nagios) is executed to start monitoring the Red Hat Storage Nodes after the nodes are added to Red Hat Storage Console. For more details, refer Red Hat Storage Console Administration Guide."
    fi
}

function disable_monitoring
{
    ret=`egrep "\"enabled\":.*false" $cfgfile`
    if [ "$ret" != "" ]
    then
        echo "RHSC Monitoring is already disabled"
    else
        # Set the value of flag
        echo "Setting the monitoring flag..."
        sed 's/"enabled":.*true/"enabled": false/g' $cfgfile > ${cfgfile}_tmp
        mv ${cfgfile}_tmp $cfgfile

        # Stop the services
        if echo $(nagios_status) | egrep -q "is running"
        then
	        service nagios stop
        fi
        if echo $(nsca_status) | egrep -q "is running"
        then
	        service nsca stop
        fi
    fi
}

function status
{
    # Check if monitoring is enable
    ret=`egrep "\"enabled\":.*true" $cfgfile`
    if [ "$ret" != "" ]
    then
        echo "RHSC monitoring is enabled."
    fi
    ret=`egrep "\"enabled\":.*false" $cfgfile`
    if [ "$ret" != "" ]
    then
        echo "RHSC monitoring is not enabled."
    fi

    # Check the status of services
    echo $(nagios_status)
    echo $(nsca_status)
}

############
# MAIN
############
if [ $# -ne 1 ]
then
    echo "Usage: rhsc-monitoring <enable/disable/status>"
    exit -1
fi

cfgfile="/etc/ovirt-engine/ui-plugins/gluster-nagios-monitoring-config.json"

# Check if RHSC setup is done already
if [ ! -f $cfgfile ]
then
	echo "RHSC setup not yet executed. This tool can be used once rhsc-setup is executed."
	exit -1
fi

# Execute the appropriate action
if [ "$1" == "enable" ]
then
    enable_monitoring
elif [ "$1" == "disable" ]
then
    disable_monitoring
elif [ "$1" == "status" ]
then
    status
else
    echo "Invalid option [$1]"
    exit -1
fi

